@@ -64,10 +64,10 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 @sweeps @miditers @varnumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
 report newretrieve newreport washn
 $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularratios @totalcases @winneritems
-toil genstar solvestar integratebox filterbox__ cleanitem
+toil genstar solvestar integratebox filterbox__ clean
 );
 
-$VERSION = '0.155';
+$VERSION = '0.161';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -468,15 +468,15 @@ sub getitersnum
 }
 
 
-sub cleanitem
+sub clean
 {
   my ( $line, $mypath, $file ) = @_;
-	$line =~ s/^$mypath// ;
-	$line =~ s/^\/// ;
-	$line =~ s/^$file// ;
-	$line =~ s/^_// ;
-  $line =~ /_(\D+)$/ ;
-  $line =~ s/_$1$// ;
+	$line =~ s/^$mypath// ; #say $tee "IN CLEAN \$line $line";
+	$line =~ s/^\/// ; #say $tee "IN CLEAN \$line $line";
+	$line =~ s/^$file// ; #say $tee "IN CLEpAN \$line $line";
+	$line =~ s/^_// ; #say $tee "IN CLEAN \$line $line";
+  $line =~ /_(\D+)$/ ; #say $tee "IN CLEAN \$line $line";
+  $line =~ s/_$1$// ; #say $tee "IN CLEAN \$line $line";
   #$line =~ s/^-// ;
   return( $line );
 }
@@ -484,14 +484,25 @@ sub cleanitem
 
 sub makefilename # IT DEFINES A FILE NAME GIVEN A %carrier.
 {
-	my %carrier = @_;
-	my $filename = "$mypath/$file" . "_";
-	my $countcase = 0;
+	my ( $carrier_r, $mypath, $file, $instn ) = @_;
+	my %carrier = %{ $carrier_r };
+	my $cleanto;
 	foreach my $key (sort {$a <=> $b} (keys %carrier) )
 	{
-		$filename = $filename . $key . "-" . $carrier{$key} . "_";
+		$cleanto = $cleanto . $key . "-" . $carrier{$key} . "_";
 	}
-	return ($filename); # IT HAS TO BE CALLED WITH: makefilename(%carrier);
+	$cleanto =~ s/_$// ;
+
+	my $to = "$mypath/$file" . "_" . "$cleanto";
+	my $cleancrypto = $instn . "__";
+	#my $cleancrypto = $instn . "-";
+	my $crypto = "$mypath/$file" . "_" . "$cleancrypto";
+	my $it;
+	$it{to} = $to;
+	$it{cleanto} = $cleanto;
+	$it{crypto} = $crypto;
+	$it{cleancrypto} = $cleancrypto;
+	return ( \%it );
 }
 
 
@@ -528,7 +539,7 @@ sub getrootname
 
 sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 {
-	my ( $transfile, $carrier_r, $file, $blockelts_r ) = @_;
+	my ( $transfile, $carrier_r, $file, $blockelts_r, $mypath, $instn ) = @_;
 	#say $tee "In extractcase; \$transfile: " . dump( $transfile) ;
 	#say $tee "In extractcase; \$carrier_r: " . dump( $carrier_r) ;
 	#say $tee "In extractcase; \$file: " . dump( $file) ;
@@ -571,9 +582,8 @@ sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 		}
 	}
 	#say $tee "In extractcase, OBTAINED \%carrier: " . dump( \%carrier ) ;
-	my $to = makefilename( %carrier ); #say $tee "In extractcase, RESULT1:; \$to: " . dump( $to) ;
-	$to = Sim::OPT::cleanitem( $to, $mypath, $file ); #say $tee "In extractcase, NAME:; \$to: " . dump( $to) ;
-	return( $to );
+	my %to = %{ makefilename( \%carrier, $mypath, $file, $instn, \%inst ) }; say $tee "In extractcase, RESULT1:; \%to: " . dump( %to ) ;
+	return( \%to );
 }
 
 
@@ -727,7 +737,7 @@ sub givesize
 	my $product = 1;
 	foreach my $elt (@slice)
 	{
-		my $stepsize = Sim::OPT::getstepsvar($elt, $countcase, $varnumberref);
+		my $stepsize = Sim::OPT::getstepsvar( $elt, $countcase, $varnumberref );
 		$product = $product * $stepsize;
 	}
 	return ($product); # TO BE CALLED WITH: givesize(\@slice, $countcase, \@varnumbers);, WHERE SLICE MAY BE @blockelts in SIM::OPT OR @presentslice OR @pastslice IN Sim::OPT::Takechance
@@ -742,22 +752,20 @@ sub wash # UNUSED. CUT.
 	foreach my $instanceref (@instances)
 	{
 		my %d = %{ $instanceref };
-		my $to = $d{to};
-		$to = Sim::OPT::cleanitem( $to, $mypath, $file );
-		push (@bag, $to);
+		my %to = %{ $d{$to} };
+		push ( @bag, $to{cleanto} );
 	}
 	my $count = 0;
 	foreach my $instanceref (@instances)
 	{
 		my %d = %{ $instanceref };
-		my $to = $d{to};
-		$to = Sim::OPT::cleanitem( $to, $mypath, $file );
-		if ( not ( $to ~~ @bag ) )
+		my %to = %{ $d{$to} };
+		if ( not ( $to{cleanto} ~~ @bag ) )
 		{
-			push ( @rightbag, \%d );
+			push ( @rightbag, $to{cleanto} );
 		}
 	}
-	return (@rightbag); # TO BE CALLED WITH wash(@instances);
+	return ( @rightbag ); # TO BE CALLED WITH wash(@instances);
 }
 
 
@@ -780,15 +788,18 @@ sub integratebox
 	my %carrier = %{ $_[1] }; #say $tee "IN INTEGRATEBOX \%carrier " . dump( \%carrier ) ;
 	my $file = $_[2];
 	my @blockelts = @{ $_[3] }; #say $tee "IN INTEGRATEBOX \@blockelts @blockelts" ;
+	my $mypath = $_[4];
 	my @newbox;
 	foreach my $eltref ( @arrelts )
 	{
 		my @elts = @{ $eltref };
 		my $target = $elts[0]; #say $tee "IN INTEGRATEBOX Target $target" ;
-		my $righttarget = extractcase( $target, \%carrier, $file, \@blockelts ); #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
+		my %righttarg = %{ extractcase( $target, \%carrier, $file, \@blockelts, $mypath ) }; #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
+		my $righttarget = $righttarg{cleanto}; say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
 		my $origin = $elts[3]; #say $tee "IN INTEGRATEBOX \$origin $origin" ;
-		my $rightorigin = extractcase( $origin, \%carrier, $file, \@blockelts ); #say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin";
-		push (@newbox, [ $righttarget, $elts[1], $elts[2], $rightorigin, $elts[4] ] );
+		my %rightorig = %{ extractcase( $origin, \%carrier, $file, \@blockelts, $mypath ) }; #say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin";
+		my $rightorigin = $rightorig{cleanto}; say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin" ;
+		push ( @newbox, [ $righttarget, $elts[1], $elts[2], $rightorigin, $elts[4] ] );
 	} #say $tee "IN INTEGRATEBOX \@newbox " . dump( @newbox ) ;
 	return ( \@newbox );
 }
@@ -1162,8 +1173,11 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	my %datastruc = %{ $d{datastruc} };
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN callblock \%dowhat" . dump( %dowhat );
 	my @varnumbers = @{ $d{varnumbers} };
+	my $instn = $d{instn}; say $tee "IN callblock \$instn" . dump( $instn );
+	my %inst = %{ $d{inst} }; say $tee "IN callblock \%inst " . dump( \%inst );
 	@varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee"IN callblock ( \@varnumbers) " . dump( @varnumbers );
 
+
 	if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
     exit(say $tee "#END RUN.");
@@ -1215,10 +1229,10 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	my @blocks = getblocks( \@sweeps, $countcase );
 
 	my $toitem = getitem( \@winneritems, $countcase, $countblock ); #say $tee "IN12 callblock \$toitem" . dump( $toitem ); #say $tee "IN12 callblock \$mypath" . dump( $mypath ); say $tee "IN12 callblock \$file" . dump( $file ); ### DDD
-	$toitem = cleanitem( $toitem, $mypath, $file ); say $tee "IN12 callblock \$toitem " . dump( $toitem );
+	$toitem = clean( $toitem, $mypath, $file ); #say $tee "IN12 callblock \$toitem " . dump( $toitem );
 
 	my $from = getline($toitem);
-	$from = cleanitem( $from, $mypath, $file ); say $tee "IN12 callblock \$from " . dump( $from );
+	$from = clean( $from, $mypath, $file ); #say $tee "IN12 callblock \$from " . dump( $from );
 
 	my $file = $dowhat{file};
 
@@ -1305,7 +1319,7 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 		dowhat => \%dowhat, varnumbers => \@varnumbers,
 		mids => \%mids, varnums => \%varnums, carrier => \%carrier,
 		carrier => \%carrier, sourceblockelts => \@sourceblockelts,
-		blocks => \@blocks, blockelts => \@blockelts } );
+		blocks => \@blocks, blockelts => \@blockelts, instn => $instn, inst => \%inst } );
 }
 
 sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
@@ -1334,9 +1348,12 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	my %varnums = %{ $d{varnums} }; say $tee "IN DEFFILES \%varnums " . dump( \%varnums );
 	my %mids = %{ $d{mids} }; say $tee "IN DEFFILES \%mids " . dump( \%mids );
 	my %carrier = %{ $d{carrier} }; say $tee "IN DEFFILES \%carrier " . dump( \%carrier );
+	my $instn = $d{instn};
+	my %inst = %{ $d{inst} };
 
 	say $tee "IN IN DEFFILES  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	my $file = $dowhat{file}; #say $tee "IN DEFFILES \$file " . dump( $file );
+	my $mypath = $dowhat{mypath};
 
 	my $starstring = tellstring( \%mids, $file ); say $tee "IN2 DEFFILES1 \$starstring " . dump( $starstring );
 	$dirfiles{starstring} = $starstring; # FOR THE OUTTER STAR SEARCH
@@ -1349,7 +1366,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 
 	sub toil
 	{
-		my ( $blockelts_r, $varnums_r, $basket_r, $c ) = @_;
+		my ( $blockelts_r, $varnums_r, $basket_r, $c, $mypath, $file ) = @_;
 		my @blockelts = @{ $blockelts_r }; #say $tee "IN TOIL \@blockelts : " . dump( @blockelts );
 		my %varnums = %{ $varnums_r }; #say $tee "IN TOIL \%varnums : " . dump( %varnums );
 
@@ -1403,7 +1420,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		foreach my $elt ( @blockelts )
 		{
 			my @dummys = ( $elt );
-			my @bix = @{ toil( \@dummys, \%varnums, \@basket, $c ) };
+			my @bix = @{ toil( \@dummys, \%varnums, \@basket, $c, $mypath, $file ) };
 			#@bix = @{ $bix[0] };
 			my @bark = @{ flattenbox( @bix ) };
 			push( @bux, @bark );
@@ -1413,7 +1430,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	else
 	{
 		say $tee "IN DEFFFILES RIGHT \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
-		@bux = @{ toil( \@blockelts, \%varnums, \@basket ) };
+		@bux = @{ toil( \@blockelts, \%varnums, \@basket, "", $mypath, $file ) };
 	} say $tee "IN DEFFILES2 \@bux: " . dump( @bux );
 	#say $tee "IN DEFFILES2 \$countblock : " . dump( $countblock );
 	#say $tee "IN DEFFILES \@blockelts : " . dump( @blockelts );
@@ -1428,7 +1445,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		{
 			say $tee "MIDITERS FOR MIDSURRS!: " . dump ( @miditers );
 			my %midsurrs = %{ $midsurrs_r }; #say $tee "IN DEFFILES \%midsurrs" . dump( \%midsurrs );
-	 		@bag = uniq( @{ integratebox( \@bux, \%midsurrs, $file, \@blockelts ) } );
+	 		@bag = uniq( @{ integratebox( \@bux, \%midsurrs, $file, \@blockelts, $mypath, \%inst ) } );
 			push( @finalbox, @bag );
 		}
 	}
@@ -1436,7 +1453,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	{
 		say $tee "IN DEFFILES RIGHT AFTER " ;
 		my @bark = @{ flattenbox( \@bux ) };
-		@finalbox = uniq( @{ integratebox( \@bark, \%carrier, $file, \@blockelts ) } );
+		@finalbox = uniq( @{ integratebox( \@bark, \%carrier, $file, \@blockelts, $mypath, \%inst ) } );
 	}
 
 	@finalbox = sort { $a->[0] <=> $b->[0] } @finalbox; say $tee "In DEFFILES5 \@finalbox!: " . dump ( @finalbox );
@@ -1451,7 +1468,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		datastruc => \%datastruc, dowhat => \%dowhat,
 		varnumbers => \@varnumbers,
 		mids => \%mids, varnums => \%varnums,
-		carrier => \%carrier
+		carrier => \%carrier, instn => $instn, inst => \%inst
 	} );
 }
 
@@ -1471,6 +1488,38 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN SETLAUNCH \%dowhat" . dump( %dowhat );
 	my $toitem = $d{toitem} ; #say $tee "IN12 SETLAUNCH \$toitem : " . dump( $toitem );
 	my $from = $d{from}; #say $tee "IN12 SETLAUNCH \$from : " . dump( $from );
+	my $instn = $d{instn}; say $tee "IN12 SETLAUNCH \$instn : " . dump( $instn );
+	my %inst = %{ $d{inst} }; say $tee "IN12 SETLAUNCH \%inst : " . dump( \%inst );
+
+	#sub cleaninst
+	#{
+	#	my %inst = %{ $_[0] };
+	#	my %newinst;
+	#	my @cleans;
+	#	foreach my $in ( keys %inst )
+	#	{
+	#		push( @cleans, $in{cleanto} );
+	#	}
+	#	uniq( @cleans );
+	#
+	#	foreach my $el (  @cleans )
+	#	{
+	#		foreach my $in ( keys %inst )
+	#		{
+	#			if( $in{cleanto} eq $el )
+	#			{
+	#				$newinst{$in}{cleanto} = $in{cleanto};
+	#				$newinst{$in}{to} = $in{to};
+	#				$newinst{$in}{crypto} = $in{crypto};
+	#				$newinst{$in}{cleancrypto} = $in{cleancrypto};
+	#				next;
+	#			}
+	#		}
+	#	}
+	#	return( \%newinst )
+	#}
+	#
+	#%inst = %{ cleaninst( \%inst ) }; say $tee "AFTER CLEANINST IN SETLAUNCH \%inst : " . dump( \%inst );
 
 	my @blockelts = @{ getblockelts(\@sweeps, $countcase, $countblock ) };
 	my @blocks = getblocks(\@sweeps, $countcase); #say $tee "IN SETcountstep => $countstep,LAUNCH \@blocks " . dump( @blocks );
@@ -1481,33 +1530,49 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	#say $tee "IN IN SETLAUNCH  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 
 	my ( @instances );
+	my %starters = %{ extractcase( "", \%carrier, $file, \@blockelts, $mypath, "" ) };
+	$dirfiles{starter} = $starters{cleanto}; say $tee "IN SETLAUNCH \$dirfiles{starter}" . dump( $dirfiles{starter} );
 
 	my $count = 0;
 	foreach my $elt ( @basket )
-	{	#say $tee "DOING";
+	{
 
 		my $newpars = $$elt[0];
-		my $countvar = $$elt[1];
-		my $countstep = $$elt[2];
+		my $countvar = $$elt[1]; say $tee "IN SETLAUNCH \$countvar! " . dump( $countvar );
+		my $countstep = $$elt[2]; say $tee "IN SETLAUNCH \$countstep! " . dump( $countstep );
 		my $oldpars = $$elt[3];
-		my $to = extractcase( $newpars, \%carrier, $file, \@blockelts );
-		my $origin = extractcase( $oldpars, \%carrier, $file, \@blockelts );
-		my $c = $$elt[4];
+		my %to = %{ extractcase( $newpars, \%carrier, $file, \@blockelts, $mypath, $instn ) };
+		#say $tee "IN SETLAUNCH \%to" . dump( \%to );
+		#say $tee "IN SETLAUNCH \$to{cleanto}" . dump( $to{cleanto} );
+		#say $tee "IN SETLAUNCH \$inst{\$to{cleanto}}" . dump( $inst{$to{cleanto}} );
+		#say $tee "IN SETLAUNCH \%inst" . dump( \%inst );
 
-		push ( @instances,
+		unless( $inst{$to{cleanto}} ne "" )
 		{
-			countcase => $countcase, countblock => $countblock,
-			miditers => \@miditers,  winneritems => \@winneritems,
-			dirfiles => \%dirfiles, c => $c, toitem => $toitem, from => $from,
-			to => $to, countvar => $countvar, countstep => $countstep,
-			sweeps => \@sweeps, dowhat => \%dowhat,
-			sourcesweeps => \@sourcesweeps, datastruc => \%datastruc,
-			varnumbers => \@varnumbers, blocks => \@blocks,
-			blockelts => \@blockelts, mids => \%mids, varnums => \%varnums,
-			countinstance => $count, carrier => \%carrier, origin => $origin
-		} );
-		$count++;
+			$inst{$to{cleanto}} = $to{crypto};
+			$inst{$to{crypto}} = $to{cleanto};
 
+			my %orig = %{ extractcase( $oldpars, \%carrier, $file, \@blockelts, $mypath ) };
+			my $origin = $orig{cleanto};
+			#say $tee "IN SETLAUNCH \$origin" . dump( \$origin ) . "\n\n";
+			my $c = $$elt[4];
+			say $tee "INSTANCE!: $instn";
+			push ( @instances,
+			{
+				countcase => $countcase, countblock => $countblock,
+				miditers => \@miditers,  winneritems => \@winneritems,
+				dirfiles => \%dirfiles, c => $c, toitem => $toitem, from => $from,
+				to => \%to, countvar => $countvar, countstep => $countstep,
+				sweeps => \@sweeps, dowhat => \%dowhat,
+				sourcesweeps => \@sourcesweeps, datastruc => \%datastruc,
+				varnumbers => \@varnumbers, blocks => \@blocks,
+				blockelts => \@blockelts, mids => \%mids, varnums => \%varnums,
+				countinstance => $count, carrier => \%carrier, origin => $origin,
+				instn => $instn, inst => \%inst
+			} );
+			$instn++;
+		}
+		$count++;
 	} #say $tee "IN SETLAUNCH \@instances " . dump( @instances );
 	exe( { instances => \@instances, dirfiles => \%dirfiles } );
 }
@@ -1515,7 +1580,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 sub exe
 {
 	my %dat = %{ $_[0] };
-	my @instances = @{ $dat{instances} }; say $tee "IN EXE \@instances " . dump( @instances );
+	my @instances = @{ $dat{instances} }; #say $tee "IN EXE \@instances " . dump( @instances );
 	my %dirfiles = %{ $dat{dirfiles} }; #say $tee "IN EXE \%dirfiles " . dump( %dfromirfiles );
 
 	my %d = %{ $instances[0] }; #say $tee "IN EXE \%d!!! " . dump( \%d );
@@ -1529,18 +1594,25 @@ sub exe
 
 	my %datastruc = %{ $d{datastruc} }; #say $tee "IN EXE \%datastruc " . dump( %datastruc );
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN EXE \%dowhat " . dump( %dowhat );
-	my $toitem = $d{toitem}; say $tee "IN12 EXE \$toitem : " . dump( $toitem );
-	my $from = $d{from}; say $tee "IN12 EXE \$from : " . dump( $from );
-	my $to = $d{to}; say $tee "IN12 EXE \$to : " . dump( $to );
+	my $toitem = $d{toitem}; #say $tee "IN12 EXE \%toitem : " . dump( \%toitem );
+	my $from = $d{from}; #say $tee "IN12 EXE \%from : " . dump( %from );
+	my %to = %{ $d{to} }; say $tee "IN12 EXE \%to : " . dump( %to );
 	my $countvar = $d{countvar}; say $tee "IN12 EXE \$countvar : " . dump( $countvar );
 	my $countstep = $d{countstep}; say $tee "IN12 EXE \$countstep : " . dump( $countstep );
+	my $instn = $d{instn};
 	say $tee "IN EXE  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	my %inst = %{ $d{inst} };
 
 	my $precomputed = $dowhat{precomputed}; say $tee "IN EXE \$precomputed " . dump( $precomputed ); #NEW
   my @takecolumns = @{ $dowhat{takecolumns} }; say $tee "IN EXE \@takecolumns " . dump( @takecolumns ); #NEW
 	my ( @simcases, @simstruct );
 	say $tee "#Performing a search on case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 
+	my $cryptlinks = "$mypath/$file" . "_" . "$countcase" . "_cryptlinks.pl";
+	open ( CRYPTLINKS, ">$cryptlinks" ) or die;
+	say CRYPTLINKS "" . dump( \%inst );
+	close CRYPTLINKS;
+
 	if ( $dowhat{morph} eq "y" )
 	{
 		say $tee "#Calling morphing operations for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
@@ -1662,16 +1734,17 @@ sub genstar
 
 sub start
 {
-
-
 ###########################################
-say "\nHi. This is Sim::OPT, version $VERSION.
+say "\nThis is Sim::OPT, version $VERSION.
 Please insert the name of a configuration file (Unix path).\n";
 ###########################################
 	$configfile = <STDIN>;
 	chomp $configfile;
-	if (-e $configfile ) { ; }
-	else { &start; }
+	if (-e $configfile )
+	{
+		return( $configfile );
+	}
+	else { start; }
 }
 
 
@@ -1680,11 +1753,19 @@ Please insert the name of a configuration file (Unix path).\n";
 
 sub opt
 {
-	&start;
+	my $configfile = start;
 	#eval `cat $configfile`; # The file where the program data are
 	my ( @miditers, @varnumbers );
 	require $configfile;
 
+	my $instn = 1;
+	my %inst;
+
+	if ( $dowhat{mypath} eq "" )
+	{
+		$dowhat{mypath} = $mypath;
+	}
+
 	if ( scalar( @miditers == 0 ) )
 	{
 		@miditers = @mediumiters;
@@ -1702,13 +1783,19 @@ sub opt
 		$tofile = "$mypath/$file-tofile.txt";
 	}
 
+	if ( $dowhat{tofile} eq "" )
+	{
+		$dowhat{tofile} = $tofile;
+	}
+
 	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 
 #	if ($casefile) { eval `cat $casefile` or die( "$!" ); }
 #	if ($chancefile) { eval `cat $chancefile` or die( "$!" ); }
 
-	print "\nNow in Sim::OPT. \n";
+	say $tee "\nNow in Sim::OPT. \n";
 	$dowhat{file} = $file;
+	#say $tee "IN OPT \%vals " . dump( %vals );
 
   if ( $dowhat{randomsweeps} eq "yes" ) #IT SHUFFLES  @sweeps UNDER REQUESTED SETTING.
   {
@@ -1985,7 +2072,7 @@ sub opt
 				callblock( { countcase => $countcase, countblock => $countblock,
 					miditers => \@miditers, varnumbers => \@varnumbers, winneritems => \@winneritems, sweeps => \@sweeps,
 					sourcesweeps => \@sourcesweeps, datastruc => \%datastruc, dirfiles => \%dirfiles,
-					dowhat => \%dowhat } );
+					dowhat => \%dowhat, instn => $instn, inst => \%inst } );
 					$countstring++;
 					$dirfiles{countstring} = $countstring;
 			}
@@ -2026,14 +2113,13 @@ sub opt
 				$count++;
 			}
 			$datastruc = [ @arr ];
-
 			#say $tee "PRE CALLCASE \%dowhat" . dump( %dowhat );
 			callblock
 			(	{ countcase => $countcase, countblock => $countblock,
 					miditers => \@miditers, varnumbers => \@varnumbers, winneritems => \@winneritems,
 					sweeps => \@sweeps, sourcesweeps => \@sourcesweeps,
 					datastruc => \%datastruc, dowhat => \%dowhat,
-					dirfiles => \%dirfiles } );
+					dirfiles => \%dirfiles, instn => $instn, inst => \%inst } );
 		}
 	}
 	elsif ( ( $target eq "parcoord3d" ) and (@chancedata) and ( $dimchance ) )
