@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.111'; # our $VERSION = '';
+$VERSION = '0.115'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -131,11 +131,13 @@ sub descend
   my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "IN ENTRY DESCEND \@sourcesweeps : " . dump( @sourcesweeps );
   my @rootnames = @{ $d{rootnames} }; ######
   my @winneritems = @{ $d{winneritems} }; say $tee "IN ENTRY DESCEND \@winneritems : " . dump( @winneritems );
+  my $instn = $d{instn}; say $tee "IN ENTRY DESCEND \$instn : " . dump( $instn );
+  my %inst = %{ $d{inst} }; say $tee "IN ENTRY DESCEND \%inst : " . dump( \%inst );
   my %dowhat = %{ $d{dowhat} }; ######
 
-  my $skipfile = $dowhat{skipfile};
-  my $skipsim = $dowhat{skipsim};
-  my $skipreport = $dowhat{skipreport};
+  my $skipfile = $vals{skipfile};
+	my $skipsim = $vals{skipsim};
+	my $skipreport = $vals{skipreport};
 
   if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
@@ -146,12 +148,12 @@ sub descend
 
 	my @blocks = @{ $d{blocks} }; say $tee "IN ENTRY DESCEND \@blocks : " . dump( @blocks );
 	my $toitem = Sim::OPT::getitem( \@winneritems, $countcase, $countblock ); say $tee "IN12 ENTRY DESCEND \$toitem : " . dump( $toitem );
-  $toitem = Sim::OPT::cleanitem( $toitem, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$toitem : " . dump( $toitem );
+  $toitem = Sim::OPT::clean( $toitem, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$toitem : " . dump( $toitem );
   my $from = Sim::OPT::getline( $toitem ); #say $tee "IN ENTRY DESCEND \$from : " . dump( $from );
 	say $tee "IN ENTRY DESCEND \$varnumbers[\$countcase]" . dump( $varnumbers[$countcase] );
-  $from = Sim::OPT::cleanitem( $from, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$from : " . dump( $from );
+  $from = Sim::OPT::clean( $from, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$from : " . dump( $from );
   my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase);
-  $rootname = Sim::OPT::cleanitem( $rootname, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$rootname : " . dump( $rootname );
+  $rootname = Sim::OPT::clean( $rootname, $mypath, $file ); say $tee "IN12 ENTRY DESCEND \$rootname : " . dump( $rootname );
   my %varnums = %{ $d{varnums} }; say $tee "IN ENTRY DESCEN \%varnums" . dump( %varnums );
   my %mids = %{ $d{mids} }; say $tee "IN ENTRY DESCEND \%mids" . dump( \%mids );
   my %carrier = %{ $d{carrier} }; say $tee "IN ENTRY DESCEND \%carrier" . dump( \%carrier );
@@ -288,10 +290,7 @@ sub descend
   my @winneritems = @{ $dat{winneritems} }; say $tee "IN DESCEND \@winneritems " . dump(@winneritems);
   my $countvar = $dat{countvar}; say $tee "IN DESCEND \$countvar " . dump( $countvar );
   my $countstep = $dat{countstep}; say $tee "IN DESCEND \$countstep " . dump( $countstep );
-  #my $to = $dat{to};
-  #$to = Sim::OPT::cleanitem( $to, $mypath, $file );
-  #my $origin = $dat{origin};
-  #$origin = Sim::OPT::cleanitem( $origin, $mypath, $file );
+
 
   my $counthold = 0;
 
@@ -299,8 +298,8 @@ sub descend
 
   my $word = join( ", ", @blockelts ); ###NEW
 
-  my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varnumbers);
   my $varnumber = $countvar;
+  my $stepsvar = $varnums{$countvar};
 
   say $tee "Descending into case " . ( plus1($countcase) ) . ", block " . ( plus1($countblock) ) . ".";
 
@@ -614,9 +613,9 @@ sub descend
 
   sub sortmixed
   {
-    my ( $weighttwo, $sortmixed, $searchname, $entryfile, $exitfile, $orderedfile, $outstarmode ) = @_;
+    my ( $weighttwo, $sortmixed, $searchname, $entryfile, $exitfile, $orderedfile, $outstarmode, $instn, $inst_r ) = @_;
     say $tee "Processing results for case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countblock ) ) . ".";
-
+    my %inst = %{ $inst_r }; say $tee "IN SORTMIXED \%inst" . dump( \%inst );
     if ( $searchname eq "no" )###################################
     {
       open( WEIGHTTWO, $weighttwo ) or die( "$!" ); #say $tee "IN SORTMIXED \$weighttwo" . dump( $weighttwo );
@@ -634,13 +633,27 @@ sub descend
       #{
       #  open( SORTMIXED, ">$sortmixed" ) or die( "$!" );
       #}
+      #my ( @crypteds, @cleans );
+      #foreach my $el ( %inst )
+      #{
+      #  push( @cleans, $el{cleanto} );
+      #  push( @crypteds, $el{crypto} );
+      #}
+      #
+      #foreach my $line ( @lines )
+      #{
+      #  #chomp $line;
+      #  $line =~ s/\,+$//;
+      #  $line =~ s/"//g;
+      #
+      #  my $counter = 0;
+      #  foreach my $clean ( @cleans )
+      #  {
+      #    my $crypted = $crypteds{$counter};
+      #    $line =~ s/$crypted/$clean/ ;
+      #  }
+      #}
 
-      foreach my $line ( @lines )
-      {
-        #chomp $line;
-        $line =~ s/\,+$//;
-        $line =~ s/"//g;
-      }
       @lines = uniq( @lines );
 
       #say TOFILE "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
@@ -791,7 +804,7 @@ sub descend
 
   if ( not( -e $weighttwo) ){ die; };
   if ( not( $sortmixed) ){ die; };
-  sortmixed( $weighttwo, $sortmixed, $searchname, $entryfile, $exitfile, $orderedfile, $outstarmode );
+  sortmixed( $weighttwo, $sortmixed, $searchname, $entryfile, $exitfile, $orderedfile, $outstarmode, $instn, \%inst );
 
 
 
@@ -1182,7 +1195,7 @@ sub descend
 
     #my $addfile = $file . "_";
     #$winneritem =~ s/$mypath\/$addfile// ; say $tee "IN12 TAKEOPTIMA. \$winneritem: " . dump($winneritem);
-    $winneritem =~ Sim::OPT::cleanitem( $winneritem, $mypath, $file ); #say $tee "IN12 TAKEOPTIMA. \$winneritem: " . dump($winneritem);
+    $winneritem =~ Sim::OPT::clean( $winneritem, $mypath, $file ); #say $tee "IN12 TAKEOPTIMA. \$winneritem: " . dump($winneritem);
     push ( @{ $datastruc{$closingelt} }, $winneritem );
 
     my $message;
@@ -1459,7 +1472,7 @@ sub descend
         $countstring++;
         $dirfiles{countstring} = $countstring;
         #say $tee "IN12 TAKEOPTIMA-> CLOSECASE STARPATH \$winneritem " . dump($winneritem);
-        $winneritem = Sim::OPT::cleanitem( $winneritem, $mypath, $file ); #say $tee "IN12 TAKEOPTIMA-> CLOSECASE STARPATH \$winneritem " . dump($winneritem);
+        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file ); #say $tee "IN12 TAKEOPTIMA-> CLOSECASE STARPATH \$winneritem " . dump($winneritem);
 
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem ); #say $tee "IN12 TAKEOPTIMA-> CLOSECASE STARPATH \@winneritems " . dump(@winneritems);
         #say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
@@ -1473,7 +1486,7 @@ sub descend
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat ,
-        sourcesweeps => \@sourcesweeps, } );
+        sourcesweeps => \@sourcesweeps, instn => $instn, inst => \%inst } );
       } ### END OF THE PART ON STAR CONFIGURATIONS
       else
       {
@@ -1489,7 +1502,7 @@ sub descend
         $countstring++;
         $dirfiles{countstring} = $countstring;
         #say $tee "IN12 TAKEOPTIMA-> CLOSECASE MAINPATH \$winneritem " . dump($winneritem);
-        $winneritem = Sim::OPT::cleanitem( $winneritem, $mypath, $file ); say $tee "IN12 TAKEOPTIMA-> CLOSECSE MAINPATH \$winneritem " . dump($winneritem);
+        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file ); say $tee "IN12 TAKEOPTIMA-> CLOSECSE MAINPATH \$winneritem " . dump($winneritem);
 
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem ); say $tee "IN12 TAKEOPTIMA-> CLOSECSE MAINPATH \@winneritems " . dump(@winneritems);
         #say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
@@ -1498,7 +1511,7 @@ sub descend
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat ,
-        sourcesweeps => \@sourcesweeps, } );
+        sourcesweeps => \@sourcesweeps, instn => $instn, inst => \%inst } );
       }
     }
     elsif( $countblock < $#blocks )
@@ -1582,7 +1595,7 @@ sub descend
         my $winneritem = $winnerelms[0];
 
         #say $tee "IN12 STARPATH TAKEOPTIMA->\$winneritem " . dump($winneritem);
-        $winneritem = Sim::OPT::cleanitem( $winneritem, $mypath, $file ); say $tee "IN12 STARPATH TAKEOPTIMA->\$winneritem " . dump($winneritem);
+        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file ); say $tee "IN12 STARPATH TAKEOPTIMA->\$winneritem " . dump($winneritem);
 
 				#say $tee "IN12 STARPATH TAKEOPTIMA->\@winneritems " . dump( @winneritems );
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem ); say $tee "IN12 STARPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
@@ -1598,13 +1611,13 @@ sub descend
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
-        sourcesweeps => \@sourcesweeps } );
+        sourcesweeps => \@sourcesweeps, instn => $instn, inst => \%inst } );
       } ### END OF THE PART ABOUT STAR CONFIGURATIONS
       else
       { #say $tee "NOW I SHOULD ACT.";
         #say $tee "IN BLOCK END NOT STARSIGN.";
         #say $tee "IN12 MAINPATH TAKEOPTIMA->\$winneritem " . dump( $winneritem );
-        $winneritem = Sim::OPT::cleanitem( $winneritem, $mypath, $file ); say $tee "IN12 MAINPATH TAKEOPTIMA->\$winneritem " . dump( $winneritem );
+        $winneritem = Sim::OPT::clean( $winneritem, $mypath, $file ); say $tee "IN12 MAINPATH TAKEOPTIMA->\$winneritem " . dump( $winneritem );
 
 				#say $tee "IN12 MAINPATH TAKEOPTIMA->\@winneritems " . dump( @winneritems );
         push ( @{ $winneritems[$countcase][$countblock+1] }, $winneritem ); say $tee "IN12 MAINPATH TAKEOPTIMA->\@winneritems " . dump( @winneritems );
@@ -1616,7 +1629,7 @@ sub descend
         miditers => \@miditers,  winneritems => \@winneritems,
         dirfiles => \%dirfiles, varnumbers => \@varnumbers,
         sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
-        sourcesweeps => \@sourcesweeps, } );
+        sourcesweeps => \@sourcesweeps, instn => $instn, inst => \%inst } );
       }
     }
   } # END SUB takeoptima
